#######
USAGE
#######

*******
pspbar
*******

Use subpackage ``pspbar`` as a minimalistic bar

.. code:: sh

   pspbar -m 10 1

add to sway config
.. code::

   exec pspbar -m 10 1

********
Server
********
.. include:: server.rst

*********
client
*********

.. include:: client_calls.rst
